==> moserial-2.27.4.tar.bz2: moserial-2.27.4/src/PreferencesDialog.h <==

#ifndef __SRC_PREFERENCESDIALOG_H__
#define __SRC_PREFERENCESDIALOG_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include "src/Preferences.h"

G_BEGIN_DECLS


#define MOSERIAL_TYPE_PREFERENCES_DIALOG (moserial_preferences_dialog_get_type ())
#define MOSERIAL_PREFERENCES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_PREFERENCES_DIALOG, moserialPreferencesDialog))
#define MOSERIAL_PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_PREFERENCES_DIALOG, moserialPreferencesDialogClass))
#define MOSERIAL_IS_PREFERENCES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_PREFERENCES_DIALOG))
#define MOSERIAL_IS_PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_PREFERENCES_DIALOG))
#define MOSERIAL_PREFERENCES_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_PREFERENCES_DIALOG, moserialPreferencesDialogClass))

typedef struct _moserialPreferencesDialog moserialPreferencesDialog;
typedef struct _moserialPreferencesDialogClass moserialPreferencesDialogClass;
typedef struct _moserialPreferencesDialogPrivate moserialPreferencesDialogPrivate;

struct _moserialPreferencesDialog {
	GObject parent_instance;
	moserialPreferencesDialogPrivate * priv;
};

struct _moserialPreferencesDialogClass {
	GObjectClass parent_class;
};


moserialPreferencesDialog* moserial_preferences_dialog_construct (GType object_type, GtkBuilder* builder);
moserialPreferencesDialog* moserial_preferences_dialog_new (GtkBuilder* builder);
void moserial_preferences_dialog_ok (moserialPreferencesDialog* self, GtkButton* button);
void moserial_preferences_dialog_show (moserialPreferencesDialog* self, Preferences* preferences, gboolean recording);
void moserial_preferences_dialog_cancel (moserialPreferencesDialog* self, GtkWidget* w);
gboolean moserial_preferences_dialog_hide (moserialPreferencesDialog* self, GtkWidget* w);
void moserial_preferences_dialog_systemFontToggled (moserialPreferencesDialog* self, GtkCheckButton* button);
void moserial_preferences_dialog_enableTimeoutToggled (moserialPreferencesDialog* self, GtkCheckButton* button);
GtkBuilder* moserial_preferences_dialog_get_builder (moserialPreferencesDialog* self);
GType moserial_preferences_dialog_get_type (void);


G_END_DECLS

#endif

==> moserial-2.27.5.tar.bz2: moserial-2.27.5/src/PreferencesDialog.h <==

#ifndef __SRC_PREFERENCESDIALOG_H__
#define __SRC_PREFERENCESDIALOG_H__

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include "src/Preferences.h"

G_BEGIN_DECLS


#define MOSERIAL_TYPE_PREFERENCES_DIALOG (moserial_preferences_dialog_get_type ())
#define MOSERIAL_PREFERENCES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), MOSERIAL_TYPE_PREFERENCES_DIALOG, moserialPreferencesDialog))
#define MOSERIAL_PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), MOSERIAL_TYPE_PREFERENCES_DIALOG, moserialPreferencesDialogClass))
#define MOSERIAL_IS_PREFERENCES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), MOSERIAL_TYPE_PREFERENCES_DIALOG))
#define MOSERIAL_IS_PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), MOSERIAL_TYPE_PREFERENCES_DIALOG))
#define MOSERIAL_PREFERENCES_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), MOSERIAL_TYPE_PREFERENCES_DIALOG, moserialPreferencesDialogClass))

typedef struct _moserialPreferencesDialog moserialPreferencesDialog;
typedef struct _moserialPreferencesDialogClass moserialPreferencesDialogClass;
typedef struct _moserialPreferencesDialogPrivate moserialPreferencesDialogPrivate;

struct _moserialPreferencesDialog {
	GObject parent_instance;
	moserialPreferencesDialogPrivate * priv;
};

struct _moserialPreferencesDialogClass {
	GObjectClass parent_class;
};


moserialPreferencesDialog* moserial_preferences_dialog_construct (GType object_type, GtkBuilder* builder);
moserialPreferencesDialog* moserial_preferences_dialog_new (GtkBuilder* builder);
void moserial_preferences_dialog_ok (moserialPreferencesDialog* self, GtkButton* button);
void moserial_preferences_dialog_show (moserialPreferencesDialog* self, Preferences* preferences, gboolean recording);
void moserial_preferences_dialog_cancel (moserialPreferencesDialog* self, GtkWidget* w);
gboolean moserial_preferences_dialog_hide (moserialPreferencesDialog* self);
void moserial_preferences_dialog_systemFontToggled (moserialPreferencesDialog* self, GtkCheckButton* button);
void moserial_preferences_dialog_enableTimeoutToggled (moserialPreferencesDialog* self, GtkCheckButton* button);
GtkBuilder* moserial_preferences_dialog_get_builder (moserialPreferencesDialog* self);
GType moserial_preferences_dialog_get_type (void);


G_END_DECLS

#endif
